"""Constants"""

# OAuth2 credentials
OAUTH2_APP_ID = "com.ge.kitchen.wca.prd.android"
OAUTH2_CLIENT_ID = "564c31616c4f7474434b307435412b4d2f6e7672"
OAUTH2_CLIENT_SECRET = "6476512b5246446d452f697154444941387052645938466e5671746e5847593d"
OAUTH2_REDIRECT_URI = "brillion.4e617a766474657344444e562b5935566e51324a://oauth/redirect"

LOGIN_URL = "https://accounts.brillion.geappliances.com"
API_URL = "https://api.brillion.geappliances.com"
SECURE_URL = "https://secure.brillion.geappliances.com"

EVENT_ADD_APPLIANCE = "add_appliance"
EVENT_APPLIANCE_INITIAL_UPDATE = "appliance_got_type"
EVENT_APPLIANCE_STATE_CHANGE = "appliance_state_change"
EVENT_APPLIANCE_UPDATE_RECEIVED = "appliance_updated_received"
EVENT_CONNECTED = "connected"
EVENT_DISCONNECTED = "disconnected"
EVENT_GOT_APPLIANCE_LIST = "got_appliance_list"
