from .erd_oven_state import ErdOvenState
from .const import *


OVEN_DISPLAY_STATE_MAP = {
    ErdOvenState.BAKE: STATE_OVEN_BAKE,
    ErdOvenState.BAKE_PREHEAT: STATE_OVEN_PREHEAT,
    ErdOvenState.BAKE_TWO_TEMP: STATE_OVEN_BAKE_TWO_TEMP,
    ErdOvenState.BROIL_HIGH: STATE_OVEN_BROIL_HIGH,
    ErdOvenState.BROIL_LOW: STATE_OVEN_BROIL_LOW,
    ErdOvenState.CLEAN_COOL_DOWN: STATE_OVEN_SELF_CLEAN,
    ErdOvenState.CLEAN_STAGE1: STATE_OVEN_SELF_CLEAN,
    ErdOvenState.CLEAN_STAGE2: STATE_OVEN_SELF_CLEAN,
    ErdOvenState.CONV_BAKE: STATE_OVEN_CONV_BAKE,
    ErdOvenState.CONV_BAKE_PREHEAT: STATE_OVEN_PREHEAT,
    ErdOvenState.CONV_BAKE_TWO_TEMP: STATE_OVEN_CONV_BAKE_TWO_TEMP,
    ErdOvenState.CONV_BROIL_CRISP: STATE_OVEN_CONV_BROIL_CRISP,
    ErdOvenState.CONV_BROIL_HIGH: STATE_OVEN_CONV_BROIL_HIGH,
    ErdOvenState.CONV_BROIL_LOW: STATE_OVEN_CONV_BROIL_LOW,
    ErdOvenState.CONV_MULTI_BAKE_PREHEAT: STATE_OVEN_PREHEAT,
    ErdOvenState.CONV_MULTI_TWO_BAKE: STATE_OVEN_MULTI_BAKE,
    ErdOvenState.CONV_MUTLI_BAKE: STATE_OVEN_MULTI_BAKE,
    ErdOvenState.CONV_ROAST: STATE_OVEN_CONV_ROAST,
    ErdOvenState.CONV_ROAST2: STATE_OVEN_CONV_ROAST_TWO_TEMP,
    ErdOvenState.CONV_ROAST_BAKE_PREHEAT: STATE_OVEN_PREHEAT,
    ErdOvenState.CUSTOM_CLEAN_STAGE2: STATE_OVEN_SELF_CLEAN,
    ErdOvenState.DELAY: STATE_OVEN_DELAY,
    ErdOvenState.NO_MODE: STATE_OVEN_OFF,
    ErdOvenState.PROOF: STATE_OVEN_PROOF,
    ErdOvenState.SABBATH: STATE_OVEN_SABBATH,
    ErdOvenState.STEAM_CLEAN_STAGE2: STATE_OVEN_STEAM_CLEAN,
    ErdOvenState.STEAM_COOL_DOWN: STATE_OVEN_STEAM_CLEAN,
    ErdOvenState.WARM: STATE_OVEN_WARM,
    ErdOvenState.OVEN_STATE_BAKE: STATE_OVEN_BAKE,
    ErdOvenState.OVEN_STATE_BAKED_GOODS: STATE_OVEN_BAKED_GOODS,
    ErdOvenState.OVEN_STATE_BROIL: STATE_OVEN_BROIL_HIGH,
    ErdOvenState.OVEN_STATE_CONV_BAKE: STATE_OVEN_CONV_BAKE,
    ErdOvenState.OVEN_STATE_CONV_BAKE_MULTI: STATE_OVEN_CONV_BAKE_MULTI,
    ErdOvenState.OVEN_STATE_CONV_BROIL: STATE_OVEN_CONV_BROIL_HIGH,
    ErdOvenState.OVEN_STATE_CONV_ROAST: STATE_OVEN_CONV_ROAST,
    ErdOvenState.OVEN_STATE_DUAL_BROIL_HIGH: STATE_OVEN_DUAL_BROIL_HIGH,
    ErdOvenState.OVEN_STATE_DUAL_BROIL_LOW: STATE_OVEN_DUAL_BROIL_LOW,
    ErdOvenState.OVEN_STATE_DELAY_START: STATE_OVEN_DELAY,
    ErdOvenState.OVEN_STATE_FROZEN_PIZZA: STATE_OVEN_FROZEN_PIZZA,
    ErdOvenState.OVEN_STATE_FROZEN_PIZZA_MULTI: STATE_OVEN_FROZEN_PIZZA,
    ErdOvenState.OVEN_STATE_FROZEN_SNACKS: STATE_OVEN_FROZEN_SNACKS,
    ErdOvenState.OVEN_STATE_FROZEN_SNACKS_MULTI: STATE_OVEN_FROZEN_SNACKS,
    ErdOvenState.OVEN_STATE_PROOF: STATE_OVEN_PROOF,
    ErdOvenState.OVEN_STATE_SELF_CLEAN: STATE_OVEN_SELF_CLEAN,
    ErdOvenState.OVEN_STATE_SPECIAL_X: STATE_OVEN_SPECIAL,
    ErdOvenState.OVEN_STATE_STEAM_START: STATE_OVEN_STEAM_CLEAN,
    ErdOvenState.OVEN_STATE_WARM: STATE_OVEN_WARM,
    ErdOvenState.STATUS_DASH: STATE_OVEN_OFF,
}
