STATE_OVEN_BAKE = "Bake"
STATE_OVEN_BAKE_TWO_TEMP = "Bake (Two Temp.)"
STATE_OVEN_BAKED_GOODS = "Baked Goods"
STATE_OVEN_BROIL_HIGH = "Broil (High)"
STATE_OVEN_BROIL_LOW = "Broil (Low)"
STATE_OVEN_CONV_BAKE = "Convection Bake"
STATE_OVEN_CONV_BAKE_TWO_TEMP = "Convection Bake (Two Temp.)"
STATE_OVEN_CONV_BROIL_CRISP = "Convection Broil (Crisp)"
STATE_OVEN_CONV_BROIL_HIGH = "Convection Broil (High)"
STATE_OVEN_CONV_BROIL_LOW = "Convection Broil (Low)"
STATE_OVEN_CONV_BAKE_MULTI = "Convection Multi Bake"
STATE_OVEN_CONV_ROAST = "Convection Roast"
STATE_OVEN_CONV_ROAST_TWO_TEMP = "Convection Roast (Two Temp.)"
STATE_OVEN_DUAL_BROIL_HIGH = "Dual Broil (High)"
STATE_OVEN_DUAL_BROIL_LOW = "Dual Broil (Low)"
STATE_OVEN_DELAY = "Delayed Start"
STATE_OVEN_FROZEN_PIZZA = "Frozen Pizza"
STATE_OVEN_FROZEN_SNACKS = "Frozen Snacks"
STATE_OVEN_MULTI_BAKE = "Multi Bake"
STATE_OVEN_PREHEAT = "Preheat"
STATE_OVEN_PROBE = "Probe"
STATE_OVEN_PROOF = "Proof"
STATE_OVEN_OFF = "Off"
STATE_OVEN_SABBATH = "Sabbath Mode"
STATE_OVEN_SELF_CLEAN = "Self Clean"
STATE_OVEN_SPECIAL = "Special"
STATE_OVEN_STEAM_CLEAN = "Steam Clean"
STATE_OVEN_TIMED = "Timed"
STATE_OVEN_UNKNOWN = "Unknown"
STATE_OVEN_WARM = "Keep Warm"
